#!/bin/sh
# Upgrade Helper Script for Mac OS X
# Copyright 2015 Health Info Net AG

function delete_temporary_file {
  if [[ -e "$tempfile" ]]; then
    rm -f "$tempfile" > /dev/null 2>&1
  fi  
}

# Set IFS to a newline character
IFS=$'\n'

# Check the command line parameter
if [[ -z "$1" || ! -e "$1" ]]; then
  exit 1
fi

# Create a temporary file
basename="$(basename "$0")" || exit 1
tempfile="$(mktemp -t "$basename")" || exit 1

# Delete the temporary file on exit
trap delete_temporary_file EXIT

# Attach (mount) the disk image
hdiutil attach -plist "$1" > "$tempfile" || exit 1

# Parse the dev entry and the mount point
result=$(perl -MMac::Processes "$0.pl" "$tempfile") || exit 1
delete_temporary_file
array=($result)
devEntry="${array[0]}"
mountPoint="${array[1]}"

# Sanity checks
if [[ -z "$devEntry" || -z "$mountPoint" ]]; then
  exit 1
fi
if [[ ! -e "$devEntry" || ! -e "$mountPoint" ]]; then
  exit 1
fi

# Run all applications on the disk image
applications="$mountPoint/*.app"
for application in $applications
do
  open -a "$application"
done

# Periodically try to detach (unmount) the disk image
while [[ -e "$mountPoint" ]]
do
  hdiutil detach "$devEntry" > /dev/null 2>&1 || /bin/sleep 1
done
